import type HasFieldData from './Interfaces/HasFieldData';
import type HasHelpData from './Interfaces/HasHelpData';
import type Fieldset from './Fieldset';
import type HasChoicesData from './Interfaces/HasChoicesData';
import CSSElement from './Abstract/CSSElement';
import Validations from './Helpers/Validations';
import Conditions from './Helpers/Conditions';
import Replacements from './Helpers/Replacements';
/**
 * Field class.
 *
 * @since 1.0.0
 */
export default class Field extends CSSElement {
    readonly fieldset: Fieldset;
    readonly fields: Field[];
    readonly type: string;
    readonly name: string;
    readonly label: string;
    readonly prefix: string;
    readonly suffix: string;
    readonly placeholder: string;
    readonly choices: HasChoicesData[];
    readonly conditions: Conditions;
    readonly validations: Validations;
    readonly replacements: Replacements;
    readonly help: HasHelpData;
    readonly params: any;
    readonly paramsCallback: any;
    readonly valueDefault: any;
    readonly valueCallback: any;
    value: any;
    private dynamicValue;
    private validated;
    private inputClasses;
    /**
     * Initializing field.
     *
     * @param name  Name of the field.
     * @param field Field object
     *
     * @since 1.0.0
     */
    constructor(fieldset: Fieldset, field: HasFieldData);
    /**
     * Sets autovalues for default or dynamic value if exists.
     *
     * @since 1.0.0
     */
    autoValue(): void;
    /**
     * Does field have choices.
     *
     * @return True if it has choices, false if not.
     *
     * @since 1.0.0
     */
    hasChoices(): boolean;
    /**
     * Validate the field.
     *
     * @return Array of errors, empty array on no errors.
     *
     * @since 1.0.0
     */
    validate(): string[];
    /**
     * Has the field already ben validated
     *
     * @return True if field has been validated, false if not.
     *
     * @since 1.0.0
     */
    hasBeenValidated(): boolean;
    /**
     * Add input class.
     *
     * @param string Name of css class to add.
     *
     * @since 1.0.0
     */
    addInputClass(name: string): void;
    /**
     * Remove input class.
     *
     * @param string Name of css class to remove.
     *
     * @since 1.0.0
     */
    removeInputClass(name: string): void;
    /**
     * Get input classes.
     *
     * @return String of CSS classes.
     *
     * @since 1.0.0
     */
    getInputClasses(): string;
}
