/**
 * Conditions class.
 *
 * @since 1.0.0
 */
export default class Conditions {
    form;
    conditions;
    /**
     * Constuctor.
     *
     * @param form Form object.
     * @param conditions Conditions.
     *
     * @since 1.0.0
     */
    constructor(form, conditions = []) {
        this.form = form;
        this.conditions = conditions;
    }
    /**
     * Checks if conditions are fullfilled.
     *
     * @returns True if fullfilled, false if not.
     *
     * @since 1.0.0
     */
    fullfilled() {
        let fullfillments = [];
        this.conditions.forEach((condition) => {
            let fullfilled = false;
            let field = this.form.getField(condition.field);
            let compareValue = this.filterCompareValue(condition.value);
            switch (condition.operator) {
                case '==':
                    fullfilled = compareValue === field.value;
                    break;
                case '!=':
                    fullfilled = compareValue !== field.value;
                    break;
                case '>':
                    fullfilled = compareValue !== field.value;
                    break;
                case '<':
                    fullfilled = compareValue !== field.value;
                    break;
                default:
                    throw new Error('Operator "' + condition.operator + '" does not exist.');
            }
            fullfillments.push(fullfilled);
        });
        return !fullfillments.includes(false);
    }
    /**
     * Filter compare value.
     *
     * This makes values like "undefined" possible.
     *
     * @param value Value to filter.
     * @returns Filtered value.
     *
     * @since 1.0.0
     */
    filterCompareValue(value) {
        switch (value) {
            case 'undefined':
                return undefined;
            default:
                return value;
        }
    }
}
